@@ -7,8 +7,8 @@ MODULE_REPR = 'League of Legends'
 
 class PyotRouting:
 
-    _regions = {"americas", "europe", "asia", "esports"}
-    _platforms = {"br1", "eun1", "euw1", "jp1", "kr", "la1", "la2", "na1", "oc1", "tr1", "ru"}
+    _regions = {"americas", "europe", "asia", "sea", "esports"}
+    _platforms = {"br1", "eun1", "euw1", "jp1", "kr", "la1", "la2", "na1", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2"}
     _platform2regions = {
         "br1": "americas",
         "eun1": "europe",
@@ -18,9 +18,14 @@ class PyotRouting:
         "la1": "americas",
         "la2": "americas",
         "na1": "americas",
-        "oc1": "americas",
+        "oc1": "sea",
         "tr1": "europe",
         "ru": "europe",
+        "ph2": "sea",
+        "sg2": "sea",
+        "th2": "sea",
+        "tw2": "sea",
+        "vn2": "sea",
     }
 
 
