@@ -1,7 +1,7 @@
 from typing import List, Iterator
 
 from pyot.conf.model import models
-from pyot.core.functional import cache_indexes, lazy_property
+from pyot.core.functional import cache_indexes, lazy_property, empty
 from pyot.utils.lol.cdragon import abs_url
 from .base import PyotCore
 
@@ -22,7 +22,7 @@ class Spell(PyotCore):
         renamed = {"game_modes": "modes"}
         rules = {"cdragon_spells_full": ["version", "locale", "?id"]}
 
-    def __init__(self, id: int = None, version: str = models.lol.DEFAULT_VERSION, locale: str = models.lol.DEFAULT_LOCALE):
+    def __init__(self, id: int = empty, version: str = models.lol.DEFAULT_VERSION, locale: str = models.lol.DEFAULT_LOCALE):
         self.initialize(locals())
 
     @cache_indexes
